.. _api:
.. module:: momoko

API
===

Classes, methods and stuff.


Connections
-----------

.. autoclass:: momoko.Pool
   :members:

.. autoclass:: momoko.Connection
   :members:

.. autofunction:: momoko.connect


Exceptions
----------

.. autoclass:: momoko.PoolError
   :members:

.. autoclass:: momoko.PartiallyConnectedError
   :members:
